@@ -1,19 +1,12 @@
 import signal
-from ._import import _import, _get_dirs, _get_files
 from ._version import version as __version__
+import miniav._miniav_base
 
 __author__ = "Simulation Based Engineering Laboratory (negrut@.wisc.edu)"
 """Simulation Based Engineering Laboratory (negrut@wisc.edu)"""
 __license__ = "BSD3"
 """BSD3"""
 
-for d in _get_dirs(__file__):
-    _import(d, globals())
-
-for f in _get_files(__file__, allowed="_miniav_base.py"):
-    _import(f, globals())
-
-
 def _signal_handler(sig, frame):
     """Signal handler that will exit if ctrl+c is recorded in the terminal window.
 
@@ -31,5 +24,5 @@ def _signal_handler(sig, frame):
 # setup the signal listener to listen for the interrupt signal (ctrl+c)
 signal.signal(signal.SIGINT, _signal_handler)
 
-del _import, _get_dirs, _get_files, signal
+del signal
 
